@@ -6,10 +6,10 @@
 
 use {
     crate::NewInterpreterError,
-    python3_sys as pyffi,
+    python3_sys as oldpyffi,
     python_packaging::interpreter::{
-        MemoryAllocatorBackend, PythonInterpreterConfig, PythonInterpreterProfile,
-        TerminfoResolution,
+        MemoryAllocatorBackend, MultiprocessingStartMethod, PythonInterpreterConfig,
+        PythonInterpreterProfile, TerminfoResolution,
     },
     std::{
         convert::TryFrom,
@@ -26,7 +26,7 @@ pub struct ExtensionModule {
     pub name: CString,
 
     /// Extension module initialization function.
-    pub init_func: unsafe extern "C" fn() -> *mut pyffi::PyObject,
+    pub init_func: unsafe extern "C" fn() -> *mut oldpyffi::PyObject,
 }
 
 /// A source for packed resources data.
@@ -217,6 +217,13 @@ pub struct OxidizedPythonInterpreterConfig<'a> {
     /// values passed to `int main()`.
     pub argvb: bool,
 
+    /// Whether the main Python interpreter run routine will detect use of multiprocessing
+    /// and run a multiprocessing worker process automatically.
+    pub multiprocessing_auto_dispatch: bool,
+
+    /// How to call `multiprocessing.set_start_method()` when `multiprocessing` is imported.
+    pub multiprocessing_start_method: MultiprocessingStartMethod,
+
     /// Whether to set sys.frozen=True.
     ///
     /// Setting this will enable Python to emulate "frozen" binaries, such as
@@ -274,6 +281,8 @@ impl<'a> Default for OxidizedPythonInterpreterConfig<'a> {
             extra_extension_modules: None,
             argv: None,
             argvb: false,
+            multiprocessing_auto_dispatch: true,
+            multiprocessing_start_method: MultiprocessingStartMethod::Auto,
             sys_frozen: false,
             sys_meipass: false,
             terminfo_resolution: TerminfoResolution::Dynamic,
@@ -405,6 +414,17 @@ impl<'a> ResolvedOxidizedPythonInterpreterConfig<'a> {
             .expect("origin should have a value")
     }
 
+    /// Resolve the effective value of `sys.argv`.
+    pub fn resolve_sys_argv(&self) -> &[OsString] {
+        if let Some(args) = &self.inner.argv {
+            args
+        } else if let Some(args) = &self.inner.interpreter_config.argv {
+            args
+        } else {
+            panic!("1 of .argv or .interpreter_config.argv should be set")
+        }
+    }
+
     /// Resolve the value to use for `sys.argvb`.
     pub fn resolve_sys_argvb(&self) -> Vec<OsString> {
         if let Some(args) = &self.inner.interpreter_config.argv {
