@@ -7,18 +7,21 @@
 use {
     crate::{
         config::{OxidizedPythonInterpreterConfig, ResolvedOxidizedPythonInterpreterConfig},
-        conversion::osstring_to_bytes,
+        conversion::cpython_osstring_to_bytes,
         error::NewInterpreterError,
         extension::{PyInit_oxidized_importer, OXIDIZED_IMPORTER_NAME, OXIDIZED_IMPORTER_NAME_STR},
-        importer::{install_path_hook, remove_external_importers, replace_meta_path_importers},
+        importer::{
+            install_path_hook, remove_external_importers, replace_meta_path_importers,
+            ImporterState,
+        },
         osutils::resolve_terminfo_dirs,
         pyalloc::PythonMemoryAllocator,
         python_resources::PythonResourcesState,
     },
-    cpython::{GILGuard, NoArgs, ObjectProtocol, PyDict, PyList, PyString, Python, ToPyObject},
+    cpython::{ObjectProtocol, PythonObject, ToPyObject},
     once_cell::sync::Lazy,
-    python3_sys as pyffi,
-    python_packaging::interpreter::TerminfoResolution,
+    python3_sys as oldpyffi,
+    python_packaging::interpreter::{MultiprocessingStartMethod, TerminfoResolution},
     std::{
         collections::BTreeSet,
         convert::{TryFrom, TryInto},
@@ -51,8 +54,8 @@ pub struct MainPythonInterpreter<'python, 'interpreter: 'python, 'resources: 'in
     config: ResolvedOxidizedPythonInterpreterConfig<'resources>,
     interpreter_guard: Option<std::sync::MutexGuard<'interpreter, ()>>,
     pub(crate) allocator: Option<PythonMemoryAllocator>,
-    _gil: Option<GILGuard>,
-    py: Option<Python<'python>>,
+    _gil: Option<cpython::GILGuard>,
+    py: Option<cpython::Python<'python>>,
     /// File to write containing list of modules when the interpreter finalizes.
     write_modules_path: Option<PathBuf>,
 }
@@ -119,12 +122,12 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
         set_pyimport_inittab(&self.config);
 
         // Pre-configure Python.
-        let pre_config = pyffi::PyPreConfig::try_from(&self.config)?;
+        let pre_config = oldpyffi::PyPreConfig::try_from(&self.config)?;
 
         unsafe {
-            let status = pyffi::Py_PreInitialize(&pre_config);
+            let status = oldpyffi::Py_PreInitialize(&pre_config);
 
-            if pyffi::PyStatus_Exception(status) != 0 {
+            if oldpyffi::PyStatus_Exception(status) != 0 {
                 return Err(NewInterpreterError::new_from_pystatus(
                     &status,
                     "Python pre-initialization",
@@ -137,15 +140,15 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
 
         if let Some(allocator) = &self.allocator {
             if self.config.allocator_raw {
-                allocator.set_allocator(pyffi::PyMemAllocatorDomain::PYMEM_DOMAIN_RAW);
+                allocator.set_allocator(oldpyffi::PyMemAllocatorDomain::PYMEM_DOMAIN_RAW);
             }
 
             if self.config.allocator_mem {
-                allocator.set_allocator(pyffi::PyMemAllocatorDomain::PYMEM_DOMAIN_MEM);
+                allocator.set_allocator(oldpyffi::PyMemAllocatorDomain::PYMEM_DOMAIN_MEM);
             }
 
             if self.config.allocator_obj {
-                allocator.set_allocator(pyffi::PyMemAllocatorDomain::PYMEM_DOMAIN_OBJ);
+                allocator.set_allocator(oldpyffi::PyMemAllocatorDomain::PYMEM_DOMAIN_OBJ);
             }
 
             if self.config.allocator_pymalloc_arena {
@@ -161,18 +164,18 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
         // custom domain allocators.
         if self.config.allocator_debug {
             unsafe {
-                pyffi::PyMem_SetupDebugHooks();
+                oldpyffi::PyMem_SetupDebugHooks();
             }
         }
 
-        let mut py_config: pyffi::PyConfig = (&self.config).try_into()?;
+        let mut py_config: oldpyffi::PyConfig = (&self.config).try_into()?;
 
         // Enable multi-phase initialization. This allows us to initialize
         // our custom importer before Python attempts any imports.
         py_config._init_main = 0;
 
-        let status = unsafe { pyffi::Py_InitializeFromConfig(&py_config) };
-        if unsafe { pyffi::PyStatus_Exception(status) } != 0 {
+        let status = unsafe { oldpyffi::Py_InitializeFromConfig(&py_config) };
+        if unsafe { oldpyffi::PyStatus_Exception(status) } != 0 {
             return Err(NewInterpreterError::new_from_pystatus(
                 &status,
                 "initializing Python core",
@@ -184,7 +187,7 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
         // importlib._bootstrap_external. This is where we work our magic to
         // inject our custom importer.
 
-        let py = unsafe { Python::assume_gil_acquired() };
+        let py = unsafe { cpython::Python::assume_gil_acquired() };
         self.py = Some(py);
 
         let oxidized_finder = if self.config.oxidized_importer {
@@ -194,6 +197,34 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
                 NewInterpreterError::new_from_pyerr(py, err, "import of oxidized importer module")
             })?;
 
+            let cb = |importer_state: &mut ImporterState| match self
+                .config
+                .multiprocessing_start_method
+            {
+                MultiprocessingStartMethod::None => {}
+                MultiprocessingStartMethod::Fork
+                | MultiprocessingStartMethod::ForkServer
+                | MultiprocessingStartMethod::Spawn => {
+                    importer_state.set_multiprocessing_set_start_method(Some(
+                        self.config.multiprocessing_start_method.to_string(),
+                    ));
+                }
+                MultiprocessingStartMethod::Auto => {
+                    // Windows uses "spawn" because "fork" isn't available.
+                    // Everywhere else uses "fork." The default on macOS is "spawn." This
+                    // is due to https://bugs.python.org/issue33725, which only affects
+                    // Python framework builds. Our assumption is we aren't using a Python
+                    // framework, so "spawn" is safe.
+                    let method = if cfg!(target_family = "windows") {
+                        "spawn"
+                    } else {
+                        "fork"
+                    };
+
+                    importer_state.set_multiprocessing_set_start_method(Some(method.to_string()));
+                }
+            };
+
             // Ownership of the resources state is transferred into the importer, where the Box
             // is summarily leaked. However, the importer tracks a pointer to the resources state
             // and will constitute the struct for dropping when it itself is dropped. We could
@@ -202,15 +233,14 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
             // there should no longer be a Python interpreter around. So it follows that the
             // importer state cannot be dropped after self.
             Some(
-                replace_meta_path_importers(py, &oxidized_importer, resources_state).map_err(
-                    |err| {
+                replace_meta_path_importers(py, &oxidized_importer, resources_state, Some(cb))
+                    .map_err(|err| {
                         NewInterpreterError::new_from_pyerr(
                             py,
                             err,
                             "initialization of oxidized importer",
                         )
-                    },
-                )?,
+                    })?,
             )
         } else {
             None
@@ -219,9 +249,9 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
         // Now proceed with the Python main initialization. This will initialize
         // importlib. And if the custom importlib bytecode was registered above,
         // our extension module will get imported and initialized.
-        let status = unsafe { pyffi::_Py_InitializeMain() };
+        let status = unsafe { oldpyffi::_Py_InitializeMain() };
 
-        if unsafe { pyffi::PyStatus_Exception(status) } != 0 {
+        if unsafe { oldpyffi::PyStatus_Exception(status) } != 0 {
             return Err(NewInterpreterError::new_from_pystatus(
                 &status,
                 "initializing Python main",
@@ -268,14 +298,14 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
                 .config
                 .resolve_sys_argvb()
                 .iter()
-                .map(|x| osstring_to_bytes(py, x.clone()))
+                .map(|x| cpython_osstring_to_bytes(py, x.clone()))
                 .collect::<Vec<_>>();
 
-            let args = PyList::new(py, &args_objs);
+            let args = cpython::PyList::new(py, &args_objs);
             let argvb = b"argvb\0";
 
             let res = args.with_borrowed_ptr(py, |args_ptr| unsafe {
-                pyffi::PySys_SetObject(argvb.as_ptr() as *const i8, args_ptr)
+                oldpyffi::PySys_SetObject(argvb.as_ptr() as *const i8, args_ptr)
             });
 
             match res {
@@ -289,7 +319,7 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
         let oxidized = b"oxidized\0";
 
         let res = py.True().with_borrowed_ptr(py, |py_true| unsafe {
-            pyffi::PySys_SetObject(oxidized.as_ptr() as *const i8, py_true)
+            oldpyffi::PySys_SetObject(oxidized.as_ptr() as *const i8, py_true)
         });
 
         match res {
@@ -301,7 +331,7 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
             let frozen = b"frozen\0";
 
             match py.True().with_borrowed_ptr(py, |py_true| unsafe {
-                pyffi::PySys_SetObject(frozen.as_ptr() as *const i8, py_true)
+                oldpyffi::PySys_SetObject(frozen.as_ptr() as *const i8, py_true)
             }) {
                 0 => (),
                 _ => return Err(NewInterpreterError::Simple("unable to set sys.frozen")),
@@ -310,10 +340,10 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
 
         if self.config.sys_meipass {
             let meipass = b"_MEIPASS\0";
-            let value = PyString::new(py, &origin_string);
+            let value = cpython::PyString::new(py, &origin_string);
 
             match value.with_borrowed_ptr(py, |py_value| unsafe {
-                pyffi::PySys_SetObject(meipass.as_ptr() as *const i8, py_value)
+                oldpyffi::PySys_SetObject(meipass.as_ptr() as *const i8, py_value)
             }) {
                 0 => (),
                 _ => return Err(NewInterpreterError::Simple("unable to set sys._MEIPASS")),
@@ -336,9 +366,11 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
                 let uuid_mod = py.import("uuid").map_err(|e| {
                     NewInterpreterError::new_from_pyerr(py, e, "importing uuid module")
                 })?;
-                let uuid = uuid_mod.call(py, "uuid4", NoArgs, None).map_err(|e| {
-                    NewInterpreterError::new_from_pyerr(py, e, "calling uuid.uuid()")
-                })?;
+                let uuid = uuid_mod
+                    .call(py, "uuid4", cpython::NoArgs, None)
+                    .map_err(|e| {
+                        NewInterpreterError::new_from_pyerr(py, e, "calling uuid.uuid()")
+                    })?;
                 let uuid_str = uuid
                     .str(py)
                     .map_err(|e| {
@@ -373,12 +405,12 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
     /// instance. This is because `MainPythonInterpreter.drop()` finalizes
     /// the interpreter. The borrow checker should refuse to compile code
     /// where the returned `Python` outlives `self`.
-    pub fn acquire_gil(&mut self) -> Python<'_> {
+    pub fn acquire_gil(&mut self) -> cpython::Python<'_> {
         match self.py {
             Some(py) => py,
             None => {
-                let gil = GILGuard::acquire();
-                let py = unsafe { Python::assume_gil_acquired() };
+                let gil = cpython::GILGuard::acquire();
+                let py = unsafe { cpython::Python::assume_gil_acquired() };
 
                 self._gil = Some(gil);
                 self.py = Some(py);
@@ -399,12 +431,110 @@ impl<'python, 'interpreter, 'resources> MainPythonInterpreter<'python, 'interpre
     /// the evaluation result, consider calling a function on the interpreter handle
     /// that executes code.
     pub fn py_runmain(self) -> i32 {
-        unsafe { pyffi::Py_RunMain() }
+        unsafe { oldpyffi::Py_RunMain() }
+    }
+
+    /// Run in "multiprocessing worker" mode.
+    ///
+    /// This should be called when `sys.argv[1] == "--multiprocessing-fork"`. It
+    /// will parse arguments for the worker from `sys.argv` and call into the
+    /// `multiprocessing` module to perform work.
+    pub fn run_multiprocessing(&mut self) -> cpython::PyResult<i32> {
+        // This code effectively reimplements multiprocessing.spawn.freeze_support(),
+        // except entirely in the Rust domain. This function effectively verifies
+        // `sys.argv[1] == "--multiprocessing-fork"` then parsed key=value arguments
+        // from arguments that follow. The keys are well-defined and guaranteed to
+        // be ASCII. The values are either ``None`` or an integer. This enables us
+        // to parse the arguments purely from Rust.
+
+        let argv = self.config.resolve_sys_argv().to_vec();
+
+        if argv.len() < 2 {
+            panic!("run_multiprocessing() called prematurely; sys.argv does not indicate multiprocessing mode");
+        }
+
+        let py = self.acquire_gil();
+        let kwargs = cpython::PyDict::new(py);
+
+        for arg in argv.iter().skip(2) {
+            let arg = arg.to_string_lossy();
+
+            let mut parts = arg.splitn(2, '=');
+
+            let key = parts.next().ok_or_else(|| {
+                cpython::PyErr::new::<cpython::exc::RuntimeError, _>(
+                    py,
+                    "invalid multiprocessing argument",
+                )
+            })?;
+            let value = parts.next().ok_or_else(|| {
+                cpython::PyErr::new::<cpython::exc::RuntimeError, _>(
+                    py,
+                    "invalid multiprocessing argument",
+                )
+            })?;
+
+            let value = if value == "None" {
+                py.None()
+            } else {
+                let v = value.parse::<isize>().map_err(|e| {
+                    cpython::PyErr::new::<cpython::exc::RuntimeError, _>(
+                        py,
+                        format!(
+                            "unable to convert multiprocessing argument to integer: {}",
+                            e
+                        ),
+                    )
+                })?;
+
+                v.into_py_object(py).into_object()
+            };
+
+            kwargs.set_item(py, key, value)?;
+        }
+
+        let spawn_module = py.import("multiprocessing.spawn")?;
+        spawn_module.call(py, "spawn_main", cpython::NoArgs, Some(&kwargs))?;
+
+        Ok(0)
+    }
+
+    /// Whether the Python interpreter is in "multiprocessing worker" mode.
+    ///
+    /// The `multiprocessing` module can work by spawning new processes
+    /// with arguments `--multiprocessing-fork [key=value] ...`. This function
+    /// detects if the current Python interpreter is configured for said execution.
+    pub fn is_multiprocessing(&self) -> bool {
+        let argv = self.config.resolve_sys_argv();
+
+        argv.len() >= 2 && argv[1] == "--multiprocessing-fork"
+    }
+
+    /// Runs the Python interpreter.
+    ///
+    /// If multiprocessing dispatch is enabled, this will check if the
+    /// current process invocation appears to be a spawned multiprocessing worker
+    /// and dispatch to multiprocessing accordingly.
+    ///
+    /// Otherwise, this delegates to [Self::py_runmain].
+    pub fn run(mut self) -> i32 {
+        if self.config.multiprocessing_auto_dispatch && self.is_multiprocessing() {
+            match self.run_multiprocessing() {
+                Ok(code) => code,
+                Err(e) => {
+                    let py = self.acquire_gil();
+                    e.print(py);
+                    1
+                }
+            }
+        } else {
+            self.py_runmain()
+        }
     }
 }
 
-static mut ORIGINAL_BUILTIN_EXTENSIONS: Option<Vec<pyffi::_inittab>> = None;
-static mut REPLACED_BUILTIN_EXTENSIONS: Option<Vec<pyffi::_inittab>> = None;
+static mut ORIGINAL_BUILTIN_EXTENSIONS: Option<Vec<oldpyffi::_inittab>> = None;
+static mut REPLACED_BUILTIN_EXTENSIONS: Option<Vec<oldpyffi::_inittab>> = None;
 
 /// Set PyImport_Inittab from config options.
 ///
@@ -421,10 +551,10 @@ fn set_pyimport_inittab(config: &OxidizedPythonInterpreterConfig) {
     // copy.
     unsafe {
         if ORIGINAL_BUILTIN_EXTENSIONS.is_none() {
-            let mut entries: Vec<pyffi::_inittab> = Vec::new();
+            let mut entries: Vec<oldpyffi::_inittab> = Vec::new();
 
             for i in 0.. {
-                let record = pyffi::PyImport_Inittab.offset(i);
+                let record = oldpyffi::PyImport_Inittab.offset(i);
 
                 if (*record).name.is_null() {
                     break;
@@ -442,7 +572,7 @@ fn set_pyimport_inittab(config: &OxidizedPythonInterpreterConfig) {
 
     if config.oxidized_importer {
         let ptr = PyInit_oxidized_importer as *const ();
-        extensions.push(pyffi::_inittab {
+        extensions.push(oldpyffi::_inittab {
             name: OXIDIZED_IMPORTER_NAME.as_ptr() as *mut _,
             initfunc: Some(unsafe { std::mem::transmute::<*const (), extern "C" fn()>(ptr) }),
         });
@@ -452,7 +582,7 @@ fn set_pyimport_inittab(config: &OxidizedPythonInterpreterConfig) {
     if let Some(extra_extension_modules) = &config.extra_extension_modules {
         for extension in extra_extension_modules {
             let ptr = extension.init_func as *const ();
-            extensions.push(pyffi::_inittab {
+            extensions.push(oldpyffi::_inittab {
                 name: extension.name.as_ptr() as *mut _,
                 initfunc: Some(unsafe { std::mem::transmute::<*const (), extern "C" fn()>(ptr) }),
             });
@@ -460,7 +590,7 @@ fn set_pyimport_inittab(config: &OxidizedPythonInterpreterConfig) {
     }
 
     // Add sentinel record with NULLs.
-    extensions.push(pyffi::_inittab {
+    extensions.push(oldpyffi::_inittab {
         name: std::ptr::null_mut(),
         initfunc: None,
     });
@@ -468,7 +598,7 @@ fn set_pyimport_inittab(config: &OxidizedPythonInterpreterConfig) {
     // And finally replace the static in Python's code with our instance.
     unsafe {
         REPLACED_BUILTIN_EXTENSIONS = Some(extensions);
-        pyffi::PyImport_Inittab = REPLACED_BUILTIN_EXTENSIONS.as_mut().unwrap().as_mut_ptr();
+        oldpyffi::PyImport_Inittab = REPLACED_BUILTIN_EXTENSIONS.as_mut().unwrap().as_mut_ptr();
     }
 }
 
@@ -477,7 +607,7 @@ fn set_pyimport_inittab(config: &OxidizedPythonInterpreterConfig) {
 /// Given a Python interpreter and a path to a directory, this will create a
 /// file in that directory named ``modules-<UUID>`` and write a ``\n`` delimited
 /// list of loaded names from ``sys.modules`` into that file.
-fn write_modules_to_path(py: Python, path: &Path) -> Result<(), &'static str> {
+fn write_modules_to_path(py: cpython::Python, path: &Path) -> Result<(), &'static str> {
     // TODO this needs better error handling all over.
 
     let sys = py
@@ -488,7 +618,7 @@ fn write_modules_to_path(py: Python, path: &Path) -> Result<(), &'static str> {
         .map_err(|_| "could not obtain sys.modules")?;
 
     let modules = modules
-        .cast_as::<PyDict>(py)
+        .cast_as::<cpython::PyDict>(py)
         .map_err(|_| "sys.modules is not a dict")?;
 
     let mut names = BTreeSet::new();
@@ -519,6 +649,6 @@ impl<'python, 'interpreter, 'resources> Drop
             }
         }
 
-        let _ = unsafe { pyffi::Py_FinalizeEx() };
+        let _ = unsafe { oldpyffi::Py_FinalizeEx() };
     }
 }
