@@ -3,12 +3,11 @@
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 use {
-    super::default_interpreter_config,
+    super::{default_interpreter_config, run_py_test},
     crate::MainPythonInterpreter,
-    anyhow::{anyhow, Result},
-    cpython::{ObjectProtocol, PyObject},
+    anyhow::Result,
+    cpython::ObjectProtocol,
     rusty_fork::rusty_fork_test,
-    std::path::PathBuf,
 };
 
 fn new_interpreter<'python, 'interpreter, 'resources>(
@@ -20,23 +19,7 @@ fn new_interpreter<'python, 'interpreter, 'resources>(
     Ok(interp)
 }
 
-fn run_py_test(test_filename: &str) -> Result<()> {
-    let test_dir = env!("PYEMBED_TESTS_DIR");
-    let test_path = PathBuf::from(test_dir).join(test_filename);
-
-    let mut config = default_interpreter_config();
-    config.oxidized_importer = true;
-    config.interpreter_config.run_filename = Some(test_path);
-    config.interpreter_config.buffered_stdio = Some(false);
-
-    if MainPythonInterpreter::new(config)?.py_runmain() != 0 {
-        Err(anyhow!("Python code did not exit successfully"))
-    } else {
-        Ok(())
-    }
-}
-
-fn get_importer(interp: &mut MainPythonInterpreter) -> Result<PyObject> {
+fn get_importer(interp: &mut MainPythonInterpreter) -> Result<cpython::PyObject> {
     let py = interp.acquire_gil();
 
     let sys = py.import("sys").unwrap();
