@@ -151,4 +151,4 @@ class TestImporterResourceScanning(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    unittest.main(exit=False)
+    unittest.main()
